@@ -3,7 +3,7 @@ package WiringPi::API;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '2.36.1';
 
 require XSLoader;
 XSLoader::load('WiringPi::API', $VERSION);
@@ -15,25 +15,28 @@ my @wpi_c_functions = qw(
     wiringPiSetup       wiringPiSetupSys    wiringPiSetupGpio
     wiringPiSetupPhys   pinMode             pullUpDnControl
     digitalRead         digitalWrite        digitalWriteByte
-    pwmWrite            getAlt              piBoardDev
+    pwmWrite            getAlt              piGpioLayout
     wpiToGpio           physPinToGpio       pwmSetRange
     lcdInit             lcdHome             lcdClear
     lcdDisplay          lcdCursor           lcdCursorBlink
     lcdSendCommand      lcdPosition         lcdCharDef
     lcdPutChar          lcdPuts             setInterrupt
     softPwmCreate       softPwmWrite        softPwmStop
-    sr595Setup
+    sr595Setup          bmp180Setup         bmp180Pressure
+    bmp180Temp          analogRead          analogWrite
+    physPinToWpi
 );
 
 my @wpi_perl_functions = qw(
-    setup           setup_sys       setup_phys          setup_gpio pin_mode
+    setup           setup_sys       setup_phys          setup_gpio 
     pull_up_down    read_pin        write_pin           pwm_write
-    get_alt         board_rev       wpi_to_gpio         phys_to_gpio
+    get_alt         gpio_layout     wpi_to_gpio         phys_to_gpio
     pwm_set_range   lcd_init        lcd_home            lcd_clear
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
     set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
-    shift_reg_setup
+    shift_reg_setup bmp180_setup    bmp180_pressure     bmp180_temp
+    analog_read     analog_write    pin_mode            phys_to_wpi
 );
 
 our @EXPORT_OK;
@@ -123,11 +126,21 @@ sub get_alt {
     my $pin = shift;
     return getAlt($pin);
 }
+sub analog_read {
+    shift if @_ == 2;
+    my ($pin) = @_;
+    return analogRead($pin)
+}
+sub analog_write {
+    shift if @_ == 3;
+    my ($pin, $value) = @_;
+    return analogWrite($pin, $value);
+}
 
 # board functions
 
-sub board_rev {
-    return piBoardRev();
+sub gpio_layout {
+    return piGpioLayout();
 }
 sub wpi_to_gpio {
     shift if @_ == 2;
@@ -229,6 +242,44 @@ sub shift_reg_setup {
     sr595Setup($pin_base, $num_pins, $data_pin, $clock_pin, $latch_pin);
 }
 
+# bmp180 pressure sensor functions
+
+sub bmp180_setup {
+    my ($self, $base) = @_;
+    shift if @_ == 3;
+
+    if (! defined $base || $base !~ /^\d+$/){
+        die "bmp180 setup parametermust be an integer\n";
+    }
+
+    bmp180Setup($base);
+}
+sub bmp180_temp {
+    shift if ref $_[0];
+    my ($pin, $want) = @_;
+
+    $want = 'f' if ! defined $want;
+    
+    my $temp = bmp180Temp($pin);
+    my $c = $temp / 10;
+
+    if ($want eq 'f'){
+        # returning farenheit
+        return $c * 1.8 + 32;
+    }
+    else {
+        # returning celcius
+        return $c;
+    }
+}
+sub bmp180_pressure {
+    shift if ref $_[0];
+    my ($pin) = @_;
+
+    # return kPa
+    return bmp180Pressure($pin) / 100;
+}
+
 # threading functions
 
 sub thread_create {
@@ -275,8 +326,8 @@ you must initialize the software by calling one of the C<setup*()> routines.
 
 =head1 DESCRIPTION
 
-This is an XS-based module, and requires L<wiringPi|http://wiringpi.com> to be
-installed. The C<wiringPiDev> shared library is also required (for the LCD
+This is an XS-based module, and requires L<wiringPi|http://wiringpi.com> version 2.36+
+to be installed. The C<wiringPiDev> shared library is also required (for the LCD
 functionality), but it's installed by default with C<wiringPi>.
 
 This module allows you to import the wiringPi's functions directly as-is, use
@@ -306,20 +357,22 @@ wrapper for C<wiringPiISR()> in order to make it functional here.
     lcdSendCommand      lcdPosition         lcdCharDef
     lcdPutChar          lcdPuts             setInterrupt
     softPwmCreate       softPwmWrite        softPwmStop
-    sr595Setup
+    sr595Setup          bmp180Setup         bmp180Pressure
+    bmp180Temp          analogRead          analogWrite
 
 Exported with the C<:perl> tag.
 
 Perl wrapper functions for the XS functions.
 
-    setup           setup_sys       setup_phys          setup_gpio pin_mode
+    setup           setup_sys       setup_phys          setup_gpio 
     pull_up_down    read_pin        write_pin           pwm_write
     get_alt         board_rev       wpi_to_gpio         phys_to_gpio
     pwm_set_range   lcd_init        lcd_home            lcd_clear
     lcd_display     lcd_cursor      lcd_cursor_blink    lcd_send_cmd
     lcd_position    lcd_char_def    lcd_put_char        lcd_puts
     set_interrupt   soft_pwm_create soft_pwm_write      soft_pwm_stop
-    shift_reg_setup
+    shift_reg_setup pin_mode        analog_read         analog_write
+    bmp180_setup    bmp180_pressure bmp180_temp
 
 =head1 EXPORT_TAGS
 
@@ -335,7 +388,7 @@ See L<EXPORT_OK>
 
 Exports all available exportable functions.
 
-=head1 CORE METHODS
+=head1 CORE FUNCTIONS
 
 =head2 new()
 
@@ -418,7 +471,7 @@ C<setup*()> routine you used.
 
 =head2 write_pin($pin, $state)
 
-Maps to C<void digitalWrite(int pin)>
+Maps to C<void digitalWrite(int pin, int state)>
 
 Sets the state (HIGH/on, LOW/off) of a given pin.
 
@@ -433,6 +486,38 @@ C<setup*()> routine you used.
 
 Mandatory: C<1> to turn the pin on (HIGH), and C<0> to turn it LOW (off).
 
+=head2 analog_read($pin);
+
+Maps to C<int analogRead(int pin)>
+
+Returns the data for an analog pin. Note that the Raspberry Pi doesn't have
+analog pins, so this is used when connected through an ADC or to pseudo analog
+pins.
+
+Parameters:
+    
+    $pin
+
+Mandatory: The pseudo pin number, in the pin numbering scheme dictated by
+whichever C<setup*()> routine you used.
+
+=head2 analog_write($pin, $value)
+
+Maps to C<void analogWrite(int pin, int value)>
+
+Writes the value to the corresponding analog pseudo pin.
+
+Parameters:
+
+    $pin
+
+Mandatory: The pseudo pin number, in the pin numbering scheme dictated by
+whichever C<setup*()> routine you used.
+
+    $value
+
+Mandatory: The data which you want to write to the pseudo pin. 
+
 =head2 pull_up_down($pin, $direction)
 
 Maps to C<void pullUpDnControl(int pin, int pud)>
@@ -481,11 +566,11 @@ Parameters:
 Mandatory: The pin number, in the pin numbering scheme dictated by whichever
 C<setup*()> routine you used.
 
-=head1 BOARD METHODS
+=head1 BOARD FUNCTIONS
 
 =head2 board_rev()
 
-Maps to C<int piBoardRev()>
+Maps to C<int piGpioLayout()>
 
 Returns the Raspberry Pi board's revision.
 
@@ -542,7 +627,7 @@ Parameters:
 
 Mandatory: An integer between C<0> and C<1023>.
 
-=head1 LCD METHODS
+=head1 LCD FUNCTIONS
 
 There are several methods to drive standard Liquid Crystal Displays. See
 L<wiringPiDev LCD page|http://wiringpi.com/dev-lib/lcd-library/> for full
@@ -742,7 +827,7 @@ Mandatory: The file descriptor integer returned by C<lcd_init()>.
 
 Mandatory: A string to display.
 
-=head1 SOFT PWM METHODS
+=head1 SOFT PWM FUNCTIONS
 
 Software Pulse Width Modulation is not the same as hardware PWM. It should not
 be used for critical things as it's frequency isn't 100% stable.
@@ -780,7 +865,7 @@ be lower than what was set in the C<$range> parameter to C<soft_pwm_create()>.
 
 Turns off software PWM on the C<$pin>.
 
-=head1 INTERRUPT METHODS
+=head1 INTERRUPT FUNCTIONS
 
 =head2 set_interrupt($pin, $edge, $callback)
 
@@ -853,6 +938,60 @@ Mandatory: Integer, the GPIO pin number connected to the register's C<SHCP> pin
 Mandatory: Integer, the GPIO pin number connected to the register's C<STCP> pin
 (12). Can be any GPIO pin capable of output.
 
+=head1 BMP180 PRESSURE SENSOR FUNCTIONS
+
+These functions configure and fetch data from the BMP180 pressure sensor.
+
+=head2 bmp180_setup($pin_base)
+
+Configures the system to read from a BMP180 pressure sensor.
+
+These functions can not return the raw values from the sensor. See each
+function documentation to learn how to do so.
+
+Parameters:
+
+    $pin_base
+
+Mandatory: Integer, the number at which to place the pseudo analog pins in the 
+GPIO stack. For example, if you use C<200>, pin C<200> represents the
+temperature feature of the sensor, and C<201> represents the pressure feature.
+
+Return: undef.
+
+=head2 bmp180_temp($pin, $want)
+
+Returns the temperature from the sensor.
+
+Parameters:
+
+    $pin
+
+Mandatory: Integer, represents the C<$pin_base> used in the setup function C<+ 0>.
+
+    $want
+
+Optional: C<'c'> for Celcius, and C<'f'> for Farenheit. Defaults to C<'f'>.
+
+Return: A floating point number in the requested conversion.
+
+NOTE: To get the raw sensor temperature, call the C function 
+C<bmp180Temp($pin)> directly.
+
+=head2 bmp180_pressure($pin)
+
+Returns the current air pressure in kPa.
+
+Parameters:
+
+    $pin
+
+Mandatory: Integer, represents the C<$pin_base> used in the setup function C<+ 1>.
+
+Return: A floating point number that represents the air pressure in kPa.
+
+NOTE: To get the raw sensor pressure, call the C function 
+C<bmp180Pressure($pin)> directly.
 
 head1 AUTHOR
 
